@@ -12,8 +12,10 @@
 
 # This file handles all flask-restful resources for /v3/ec2tokens
 
-import flask
 import http.client
+import urllib.parse
+
+import flask
 from keystoneclient.contrib.ec2 import utils as ec2_utils
 from oslo_serialization import jsonutils
 
@@ -25,7 +27,6 @@ from keystone import exception
 from keystone.i18n import _
 from keystone.server import flask as ks_flask
 
-
 CRED_TYPE_EC2 = 'ec2'
 
 
@@ -42,21 +43,19 @@ class EC2TokensResource(EC2_S3_Resource.ResourceBase):
             # NOTE(vish): Some client libraries don't use the port when
             # signing requests, so try again without the port.
             elif ':' in credentials['host']:
-                hostname, _port = credentials.split(':')
-                credentials['host'] = hostname
+                parsed = urllib.parse.urlsplit('//' + credentials['host'])
+                credentials['host'] = parsed.hostname
                 # NOTE(davechen): we need to reinitialize 'signer' to avoid
                 # contaminated status of signature, this is similar with
                 # other programming language libraries, JAVA for example.
                 signer = ec2_utils.Ec2Signer(creds_ref['secret'])
                 signature = signer.generate(credentials)
-                if utils.auth_str_equal(
-                        credentials['signature'], signature):
+                if utils.auth_str_equal(credentials['signature'], signature):
                     return True
             raise exception.Unauthorized(_('Invalid EC2 signature.'))
         # Raise the exception when credentials.get('signature') is None
         else:
-            raise exception.Unauthorized(
-                _('EC2 signature not supplied.'))
+            raise exception.Unauthorized(_('EC2 signature not supplied.'))
 
     @ks_flask.unenforced_api
     def post(self):
@@ -84,7 +83,9 @@ class EC2TokensAPI(ks_flask.APIBase):
             resource_kwargs={},
             rel='ec2tokens',
             resource_relation_func=(
-                json_home_relations.os_ec2_resource_rel_func))
+                json_home_relations.os_ec2_resource_rel_func
+            ),
+        )
     ]
 
 
