@@ -34,7 +34,6 @@ NULL_KEY = base64.urlsafe_b64encode(b'\x00' * 32)
 
 
 class FernetUtils:
-
     def __init__(self, key_repository, max_active_keys, config_group):
         self.key_repository = key_repository
         self.max_active_keys = max_active_keys
@@ -106,12 +105,12 @@ class FernetUtils:
 
         # This ensures the key created is not world-readable
         old_umask = os.umask(0o177)
-        if keystone_user_id and keystone_group_id:
+        if keystone_user_id is not None and keystone_group_id is not None:
             old_egid = os.getegid()
             old_euid = os.geteuid()
             os.setegid(keystone_group_id)
             os.seteuid(keystone_user_id)
-        elif keystone_user_id or keystone_group_id:
+        elif keystone_user_id is not None or keystone_group_id is not None:
             LOG.warning(
                 'Unable to change the ownership of the new key without a '
                 'keystone user ID and keystone group ID both being provided: '
@@ -135,7 +134,7 @@ class FernetUtils:
             # Do the same with group and user identifiers if a Keystone group
             # or user was supplied.
             os.umask(old_umask)
-            if keystone_user_id and keystone_group_id:
+            if keystone_user_id is not None and keystone_group_id is not None:
                 os.seteuid(old_euid)
                 os.setegid(old_egid)
             # Deal with the tmp key file
@@ -157,8 +156,8 @@ class FernetUtils:
         LOG.info('Become a valid new key: %s', valid_key_file)
 
     def _get_key_files(self, key_repo):
-        key_files = dict()
-        keys = dict()
+        key_files = {}
+        keys = {}
         for filename in os.listdir(key_repo):
             path = os.path.join(key_repo, str(filename))
             if os.path.isfile(path):
