@@ -16,8 +16,11 @@
 import itertools
 
 from oslo_log import log
-import passlib.hash
 
+from keystone.common import password_hashers
+from keystone.common.password_hashers import bcrypt
+from keystone.common.password_hashers import pbkdf2
+from keystone.common.password_hashers import scrypt
 import keystone.conf
 from keystone import exception
 from keystone.i18n import _
@@ -25,14 +28,10 @@ from keystone.i18n import _
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
-SUPPORTED_HASHERS = frozenset(
-    [
-        passlib.hash.bcrypt,
-        passlib.hash.bcrypt_sha256,
-        passlib.hash.scrypt,
-        passlib.hash.pbkdf2_sha512,
-        passlib.hash.sha512_crypt,
-    ]
+SUPPORTED_HASHERS: frozenset[type[password_hashers.PasswordHasher]] = (
+    frozenset(
+        [scrypt.Scrypt, bcrypt.Bcrypt, bcrypt.Bcrypt_sha256, pbkdf2.Sha512]
+    )
 )
 
 _HASHER_NAME_MAP = {hasher.name: hasher for hasher in SUPPORTED_HASHERS}
@@ -78,7 +77,7 @@ def _get_hasher_from_ident(hashed):
         )
 
 
-def verify_length_and_trunc_password(password):
+def verify_length_and_trunc_password(password) -> bytes:
     """Verify and truncate the provided password to the max_password_length.
 
     We also need to check that the configured password hashing algorithm does
@@ -95,7 +94,10 @@ def verify_length_and_trunc_password(password):
         CONF.identity.password_hash_algorithm == 'bcrypt'  # nosec: B105
         and CONF.identity.max_password_length > BCRYPT_MAX_LENGTH
     ):
-        msg = "Truncating password to algorithm specific maximum length %d characters."
+        msg = (
+            "Truncating password to algorithm specific maximum length %d"
+            " characters."
+        )
         LOG.warning(msg, BCRYPT_MAX_LENGTH)
         max_length = BCRYPT_MAX_LENGTH
     else:
@@ -116,7 +118,7 @@ def verify_length_and_trunc_password(password):
         raise exception.ValidationError(attribute='string', target='password')
 
 
-def check_password(password, hashed):
+def check_password(password: str, hashed: str) -> bool:
     """Check that a plaintext password matches hashed.
 
     hashpw returns the salt value concatenated with the actual hash value.
@@ -139,7 +141,7 @@ def hash_user_password(user):
     return dict(user, password=hash_password(password))
 
 
-def hash_password(password):
+def hash_password(password: str) -> str:
     """Hash a password. Harder."""
     params = {}
     password_utf8 = verify_length_and_trunc_password(password)
@@ -154,15 +156,25 @@ def hash_password(password):
 
     if CONF.identity.password_hash_rounds:
         params['rounds'] = CONF.identity.password_hash_rounds
-    if hasher is passlib.hash.scrypt:
+    if hasher is scrypt.Scrypt:
+        params["n"] = 16
         if CONF.identity.scrypt_block_size:
-            params['block_size'] = CONF.identity.scrypt_block_size
+            params["r"] = CONF.identity.scrypt_block_size
         if CONF.identity.scrypt_parallelism:
-            params['parallelism'] = CONF.identity.scrypt_parallelism
+            params["p"] = CONF.identity.scrypt_parallelism
         if CONF.identity.salt_bytesize:
-            params['salt_size'] = CONF.identity.salt_bytesize
-    if hasher is passlib.hash.pbkdf2_sha512:
+            params["salt_size"] = CONF.identity.salt_bytesize
+        return scrypt.Scrypt.hash(password_utf8, **params)
+    elif hasher is bcrypt.Bcrypt:
+        return bcrypt.Bcrypt.hash(password_utf8, **params)
+    elif hasher is bcrypt.Bcrypt_sha256:
+        return bcrypt.Bcrypt_sha256.hash(password_utf8, **params)
+    elif hasher is pbkdf2.Sha512:
         if CONF.identity.salt_bytesize:
-            params['salt_size'] = CONF.identity.salt_bytesize
-
-    return hasher.using(**params).hash(password_utf8)
+            params["salt_size"] = CONF.identity.salt_bytesize
+        return pbkdf2.Sha512.hash(password_utf8, **params)
+    else:
+        raise RuntimeError(
+            _('Password Hash Algorithm %s not implemented')
+            % CONF.identity.password_hash_algorithm
+        )
