@@ -10,22 +10,23 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_db.sqlalchemy import utils as sqlalchemyutils
 from oslo_log import log
 from sqlalchemy import orm
 from sqlalchemy.sql import expression
 
-from keystone.common import driver_hints
 from keystone.common import resource_options
 from keystone.common import sql
+import keystone.conf
 from keystone import exception
 from keystone.resource.backends import base
 from keystone.resource.backends import sql_model
 
+CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
 
 class Resource(base.ResourceDriverBase):
-
     def _encode_domain_id(self, ref):
         if 'domain_id' in ref and ref['domain_id'] is None:
             new_ref = ref.copy()
@@ -64,7 +65,6 @@ class Resource(base.ResourceDriverBase):
                 raise exception.ProjectNotFound(project_id=project_name)
             return project_ref.to_dict()
 
-    @driver_hints.truncated
     def list_projects(self, hints):
         # If there is a filter on domain_id and the value is None, then to
         # ensure that the sql filtering works correctly, we need to patch
@@ -78,10 +78,38 @@ class Resource(base.ResourceDriverBase):
         with sql.session_for_read() as session:
             query = session.query(sql_model.Project)
             query = query.filter(sql_model.Project.id != base.NULL_DOMAIN_ID)
-            project_refs = sql.filter_limit_query(
-                sql_model.Project, query, hints
+            query = sql.filter_query(sql_model.Project, query, hints)
+            marker_row = None
+            if hints.marker is not None:
+                marker_row = (
+                    session.query(sql_model.Project)
+                    .filter_by(id=hints.marker)
+                    .first()
+                )
+                if not marker_row:
+                    raise exception.MarkerNotFound(marker=hints.marker)
+
+            project_refs = sqlalchemyutils.paginate_query(
+                query,
+                sql_model.Project,
+                hints.get_limit_or_max(),
+                ["id"],
+                marker=marker_row,
             )
-            return [project_ref.to_dict() for project_ref in project_refs]
+            # Query the data
+            data = project_refs.all()
+            if hints.limit:
+                # the `common.manager.response_truncated` decorator expects
+                # that when driver truncates results it should also raise
+                # 'truncated' flag to indicate that. Since we do not really
+                # know whether there are more records once we applied filters
+                # we can only "assume" and set the flag when count of records
+                # is equal to what we have limited to.
+                # NOTE(gtema) get rid of that once proper pagination is
+                # enabled for all resources
+                if len(data) >= hints.limit["limit"]:
+                    hints.limit["truncated"] = True
+            return [project_ref.to_dict() for project_ref in data]
 
     def list_projects_from_ids(self, ids):
         if not ids:
@@ -231,7 +259,7 @@ class Resource(base.ResourceDriverBase):
             subq_tags = query.filter(
                 sql_model.ProjectTag.project_id == ptag['project_id']
             )
-            result = map(lambda x: x['name'], subq_tags.all())
+            result = (x['name'] for x in subq_tags.all())
             if set(tags) <= set(result):
                 filtered_ids.append(ptag['project_id'])
         return filtered_ids
