@@ -17,7 +17,7 @@ import abc
 from keystone import exception
 
 
-class DomainConfigDriverBase(object, metaclass=abc.ABCMeta):
+class DomainConfigDriverBase(metaclass=abc.ABCMeta):
     """Interface description for a Domain Config driver."""
 
     @abc.abstractmethod
@@ -64,8 +64,9 @@ class DomainConfigDriverBase(object, metaclass=abc.ABCMeta):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_config_options(self, domain_id, group=None, option=False,
-                            sensitive=False):
+    def list_config_options(
+        self, domain_id, group=None, option=False, sensitive=False
+    ):
         """Get a config options for a domain.
 
         :param domain_id: the domain for this option
