@@ -14,14 +14,10 @@
 
 import abc
 
-import six
-
 from keystone import exception
 
 
-@six.add_metaclass(abc.ABCMeta)
-class TrustDriverBase(object):
-
+class TrustDriverBase(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def create_trust(self, trust_id, trust, roles):
         """Create a new trust.
@@ -51,7 +47,7 @@ class TrustDriverBase(object):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_trusts_for_trustor(self, trustor):
+    def list_trusts_for_trustor(self, trustor, redelegated_trust_id=None):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
@@ -81,10 +77,13 @@ class TrustDriverBase(object):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def flush_expired_and_soft_deleted_trusts(self, project_id=None,
-                                              trustor_user_id=None,
-                                              trustee_user_id=None,
-                                              date=None):
+    def flush_expired_and_soft_deleted_trusts(
+        self,
+        project_id=None,
+        trustor_user_id=None,
+        trustee_user_id=None,
+        date=None,
+    ):
         """Flush expired and non-expired soft deleted trusts from the backend.
 
         :param project_id: ID of a project to filter trusts by.
